<?php

namespace Datamints\DatamintsPiwik\IndexedSearch\Controller;

/***************************************************************
 *  Copyright notice
 *  (c) 2017 Eva Rieger <e.rieger@datamints.com>, datamints GmbH
 *  All rights reserved
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface;
use TYPO3\CMS\Extbase\Object\ObjectManager;

/**
 * Override the parent class to track site search.
 */
class IndexedSearchController extends \TYPO3\CMS\IndexedSearch\Controller\SearchController
{
    /**
     * Overridden to insert search tracking code.
     *
     * @return array
     */
    protected function getDisplayResults($searchWords, $resultData, $freeIndexUid = -1)
    {
        $result = parent::getDisplayResults($searchWords, $resultData, $freeIndexUid);

        // Get TypoScript settings.
        /** @var \TYPO3\CMS\Extbase\Object\ObjectManager $objectManager */
        $objectManager = GeneralUtility::makeInstance(ObjectManager::class);
        /** @var \TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface $configurationManager */
        $configurationManager = $objectManager->get(ConfigurationManagerInterface::class);
        $settings = $configurationManager->getConfiguration(ConfigurationManagerInterface::CONFIGURATION_TYPE_SETTINGS,
            'DatamintsPiwik', 'Pi1');
        if (!$settings['trackIndexedSearch']) {
            return $result;
        }

        // Get search keywords.
        $keyword = array();
        foreach ($searchWords as $entry) {
            $keyword[] = $entry['sword'];
        }
        $keyword = implode(' ', $keyword);
        //Get number of results
        $resultCount = isset($resultData['count']) ? $resultData['count'] : 0;

        // Add trackSiteSearch method call.
        $trackingCode = <<<EOT
<script type="text/javascript">
var _paq = _paq || [];
_paq.push(['trackSiteSearch', '{$keyword}', false, {$resultCount}]);
</script>
EOT;
        $this->response->appendContent($trackingCode);

        return $result;
    }

}
