<?php

namespace Datamints\DatamintsPiwik\Utility;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2015 Eva Rieger <e.rieger@datamints.com>, datamints GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Utility\GeneralUtility;
use Datamints\DatamintsPiwik\Service\PiwikInfoService;
use TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface;
use TYPO3\CMS\Extbase\Object\ObjectManager;

/**
 * Processing class to get the available languages into the FlexForm of the opt-out plugin.
 */
class ItemsProcFunc {

	/**
	 * Service to get information about Piwik
	 *
	 * @var \Datamints\DatamintsPiwik\Service\PiwikInfoService
	 */
	protected $piwikInfoService;

	/**
	 * Initializes the Piwik info service.
	 */
	protected function initializePiwikInfoService() {
		// Get TypoScript settings.
		/** @var \TYPO3\CMS\Extbase\Object\ObjectManager $objectManager */
		$objectManager = GeneralUtility::makeInstance(ObjectManager::class);
		/** @var \TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface $configurationManager */
		$configurationManager = $objectManager->get(ConfigurationManagerInterface::class);
		$settings = $configurationManager->getConfiguration(ConfigurationManagerInterface::CONFIGURATION_TYPE_SETTINGS, 'DatamintsPiwik', 'Pi1');

		// Hand over settings to the info service.
		/** @var \Datamints\DatamintsPiwik\Service\PiwikInfoService $piwikInfoService */
		$this->piwikInfoService = $objectManager->get(PiwikInfoService::class);
		$this->piwikInfoService->setSettings($settings);
	}


	/**
	 * Add languages available in Piwik to an array of select options (used in FlexForm of the opt-out plugin).
	 *
	 * @param array &$config Configuration array to extend
	 * @return array
	 */
	public function optOut_getLanguages(array &$config) {
		// Initialize the Piwik info service.
		$this->initializePiwikInfoService();

		// Set up an array of available languages in Piwik.
		$language = array('**' => 'Default',);
		$language = array_merge($language, $this->piwikInfoService->getAvailableLanguages());
		$i = 0;
		foreach ($language as $key => $value) {
			$config['items'][$i][0] = $value;
			$config['items'][$i][1] = $key;
			$i++;
		}

		return $config;
	}

}
